# Changelog

<!--next-version-placeholder-->

## v0.1.2 (2024-03-12)

### Fix

* If the form has errors, don't save it. + added typing hints ([`197371a`](https://github.com/educationwarehouse/edwh-web2py-effdted-prio-grid/commit/197371a7115a27099b376ba0aafd26a26a11fe5c))

## v0.1.1 (2023-11-08)

### Fix

* Dependency toegevoegd (web2py-gluon) ([`2f83eae`](https://github.com/educationwarehouse/edwh-web2py-effdted-prio-grid/commit/2f83eae22e4d4b59ff78305f0a5f8d3af0f9f7cd))
* Version_variable name was incorrect ([`2e2770c`](https://github.com/educationwarehouse/edwh-web2py-effdted-prio-grid/commit/2e2770c4a302a173998e5337ae7b70887c742838))

## v0.1.0 (2023-11-06)
### Fix
* Semantic_release support for automatic changelog building. ([`6c418d4`](https://github.com/remcoboerma/edwh-web2py-effdted-prio-grid/commit/6c418d4ef4bbdc8eea60f2182e3869339d7f6fef))

### Documentation
* Updated repository links ([`b9ef24d`](https://github.com/remcoboerma/edwh-web2py-effdted-prio-grid/commit/b9ef24dcb50eee4232b3a325735ca2b5929a37d7))
